# zood

Github仓库网页文档 + 注释生成文档

## 主题预览

![20230101121438](https://raw.githubusercontent.com/learner-lu/picbed/master/20230101121438.png)

## 安装与使用

```bash
pip install zood
```

参见 [用户使用文档](https://luzhixing12345.github.io/zood/)

## 特性

- [x] markdown->html文档生成
- [x] markdown语法解析库
- [ ] 代码注释提取生成文档
- [ ] API说明

<!-- ## 开发

```bash
poetry build
```

```bash
poetry config pypi-token.pypi my-token
```

```bash
poetry publish
``` -->
